# Exporter

You can project a wasot file into other languages like Markdown or HTML, identified by their [Media types (MIME types)](https://developer.mozilla.org/en-US/docs/Web/HTTP/Guides/MIME_types).
To do this, wasot supports [plugins](./plugins.md) to implement exporters.
An exporter defines the projection from one block-type (see [architecture](./architecture.md) and [data model](./wasot_and_xml.md)) to one MIME type.
So, if there are 10 output formats and 20 block-types, there are 200 exporters.

Wasot files are hierarchical, which makes 